@@ -9,6 +9,7 @@ from defichain.node.modules.mining import Mining
 from defichain.node.modules.network import Network
 from defichain.node.modules.oracles import Oracles
 from defichain.node.modules.poolpair import Poolpair
+from defichain.node.modules.proposals import Proposals
 from defichain.node.modules.rawtransactions import Rawtransactions
 from defichain.node.modules.spv import Spv
 from defichain.node.modules.stats import Stats
@@ -17,3 +18,7 @@ from defichain.node.modules.util import Util
 from defichain.node.modules.vault import Vault
 from defichain.node.modules.wallet import Wallet
 from defichain.node.modules.zmq import Zmq
+
+# Util methods
+
+from defichain.node.util import BuildAmounts, BuildAddressAmounts
